==> jc-1.4.0.tar.gz: soot/jimple/toolkits/callgraph/MethodToContexts.h <==
// public final class soot.jimple.toolkits.callgraph.MethodToContexts

// class file dependencies
// @dep_class 2a7152deee1944f1 java_lang_Object
// @dep_class 2df4ee408edc52ed soot_jimple_toolkits_callgraph_MethodToContexts

// header file dependencies
// @dep_header java_lang_Object

#include "java/lang/Object.h"

#ifndef _JC_soot_jimple_toolkits_callgraph_MethodToContexts_H_
#define _JC_soot_jimple_toolkits_callgraph_MethodToContexts_H_

// Forward structure declarations
struct _jc_java_lang_Class$object;
struct _jc_java_util_Iterator$object;
struct _jc_java_util_List$object;
struct _jc_java_util_Map$object;
struct _jc_soot_SootMethod$object;

// Typedefs
typedef struct _jc_soot_jimple_toolkits_callgraph_MethodToContexts$sub_refs	_jc_soot_jimple_toolkits_callgraph_MethodToContexts$sub_refs;
typedef struct _jc_soot_jimple_toolkits_callgraph_MethodToContexts$sub_nonrefs	_jc_soot_jimple_toolkits_callgraph_MethodToContexts$sub_nonrefs;
typedef struct _jc_soot_jimple_toolkits_callgraph_MethodToContexts$refs	_jc_soot_jimple_toolkits_callgraph_MethodToContexts$refs;
typedef struct _jc_soot_jimple_toolkits_callgraph_MethodToContexts$nonrefs	_jc_soot_jimple_toolkits_callgraph_MethodToContexts$nonrefs;
typedef struct _jc_soot_jimple_toolkits_callgraph_MethodToContexts$object	_jc_soot_jimple_toolkits_callgraph_MethodToContexts$object;

typedef const struct _jc_soot_jimple_toolkits_callgraph_MethodToContexts$vmethods	_jc_soot_jimple_toolkits_callgraph_MethodToContexts$vmethods;
typedef const struct _jc_soot_jimple_toolkits_callgraph_MethodToContexts$vtable	_jc_soot_jimple_toolkits_callgraph_MethodToContexts$vtable;
typedef const struct _jc_soot_jimple_toolkits_callgraph_MethodToContexts$vtype	_jc_soot_jimple_toolkits_callgraph_MethodToContexts$vtype;

// Constructors
extern void _jc_soot_jimple_toolkits_callgraph_MethodToContexts$method$_init$fb346656e80483e8(_jc_env *, struct _jc_soot_jimple_toolkits_callgraph_MethodToContexts$object *, struct _jc_object *);

// Virtual methods
extern struct _jc_object *_jc_soot_jimple_toolkits_callgraph_MethodToContexts$method$get$f8a2e6f4762fd0df(_jc_env *, struct _jc_soot_jimple_toolkits_callgraph_MethodToContexts$object *, struct _jc_soot_SootMethod$object *);

// Virtual method descriptors
extern _jc_method _jc_soot_jimple_toolkits_callgraph_MethodToContexts$method_info$get$f8a2e6f4762fd0df;

// Virtual methods structure
struct _jc_soot_jimple_toolkits_callgraph_MethodToContexts$vmethods {
	struct _jc_object	*(*get$f8a2e6f4762fd0df)(_jc_env *, struct _jc_soot_jimple_toolkits_callgraph_MethodToContexts$object *, struct _jc_soot_SootMethod$object *);
};

// Vtable
struct _jc_soot_jimple_toolkits_callgraph_MethodToContexts$vtable {
	_jc_java_lang_Object$vmethods	java_lang_Object;
	_jc_soot_jimple_toolkits_callgraph_MethodToContexts$vmethods	soot_jimple_toolkits_callgraph_MethodToContexts;
};

// Vtype
struct _jc_soot_jimple_toolkits_callgraph_MethodToContexts$vtype {
	_jc_type			type;
	_jc_soot_jimple_toolkits_callgraph_MethodToContexts$vtable	vtable;
};

// Reference instance fields (subclass)
struct _jc_soot_jimple_toolkits_callgraph_MethodToContexts$sub_refs {
	struct _jc_object	*map;
};

// Reference instance fields (object)
struct _jc_soot_jimple_toolkits_callgraph_MethodToContexts$refs {
    _jc_soot_jimple_toolkits_callgraph_MethodToContexts$sub_refs	soot_jimple_toolkits_callgraph_MethodToContexts;
    _jc_java_lang_Object$sub_refs	java_lang_Object;
};

// Non-reference instance fields (subclass)
struct _jc_soot_jimple_toolkits_callgraph_MethodToContexts$sub_nonrefs {
};

// Non-reference instance fields (object)
struct _jc_soot_jimple_toolkits_callgraph_MethodToContexts$nonrefs {
    _jc_java_lang_Object$sub_nonrefs	java_lang_Object;
    _jc_soot_jimple_toolkits_callgraph_MethodToContexts$sub_nonrefs	soot_jimple_toolkits_callgraph_MethodToContexts;
};

// Object instance structure
struct _jc_soot_jimple_toolkits_callgraph_MethodToContexts$object {
	_jc_soot_jimple_toolkits_callgraph_MethodToContexts$refs	refs[0];
	_jc_word		lockword;
	_jc_soot_jimple_toolkits_callgraph_MethodToContexts$vtype	*vtype;
	_jc_soot_jimple_toolkits_callgraph_MethodToContexts$nonrefs	nonrefs;
};

// Type structure
extern _jc_soot_jimple_toolkits_callgraph_MethodToContexts$vtype _jc_soot_jimple_toolkits_callgraph_MethodToContexts$type;

// Array types class info structures
_JC_DECL_ARRAYS(soot_jimple_toolkits_callgraph_MethodToContexts, type);

// java.lang.Class instance
extern struct _jc_java_lang_Class$object _jc_soot_jimple_toolkits_callgraph_MethodToContexts$class_object;

#endif	/* _JC_soot_jimple_toolkits_callgraph_MethodToContexts_H_ */

==> jc-1.4.6.tar.gz: soot/jimple/toolkits/callgraph/MethodToContexts.h <==
// public final class soot.jimple.toolkits.callgraph.MethodToContexts

// class file dependencies
// @dep_class 1c4f1fc002fc96e5 java_lang_Object
// @dep_class 2df4ee408edc52ed soot_jimple_toolkits_callgraph_MethodToContexts

// header file dependencies
// @dep_header java_lang_Object

#include "java/lang/Object.h"

#ifndef _JC_soot_jimple_toolkits_callgraph_MethodToContexts_H_
#define _JC_soot_jimple_toolkits_callgraph_MethodToContexts_H_

// Forward structure declarations
struct _jc_java_lang_Class$object;
struct _jc_java_util_Iterator$object;
struct _jc_java_util_List$object;
struct _jc_java_util_Map$object;
struct _jc_soot_SootMethod$object;

// Typedefs
typedef struct _jc_soot_jimple_toolkits_callgraph_MethodToContexts$sub_refs	_jc_soot_jimple_toolkits_callgraph_MethodToContexts$sub_refs;
typedef struct _jc_soot_jimple_toolkits_callgraph_MethodToContexts$sub_nonrefs	_jc_soot_jimple_toolkits_callgraph_MethodToContexts$sub_nonrefs;
typedef struct _jc_soot_jimple_toolkits_callgraph_MethodToContexts$refs	_jc_soot_jimple_toolkits_callgraph_MethodToContexts$refs;
typedef struct _jc_soot_jimple_toolkits_callgraph_MethodToContexts$nonrefs	_jc_soot_jimple_toolkits_callgraph_MethodToContexts$nonrefs;
typedef struct _jc_soot_jimple_toolkits_callgraph_MethodToContexts$object	_jc_soot_jimple_toolkits_callgraph_MethodToContexts$object;

typedef const struct _jc_soot_jimple_toolkits_callgraph_MethodToContexts$vmethods	_jc_soot_jimple_toolkits_callgraph_MethodToContexts$vmethods;
typedef const struct _jc_soot_jimple_toolkits_callgraph_MethodToContexts$vtable	_jc_soot_jimple_toolkits_callgraph_MethodToContexts$vtable;
typedef const struct _jc_soot_jimple_toolkits_callgraph_MethodToContexts$vtype	_jc_soot_jimple_toolkits_callgraph_MethodToContexts$vtype;

// Constructors
extern void _jc_soot_jimple_toolkits_callgraph_MethodToContexts$method$_init$fb346656e80483e8(_jc_env *, struct _jc_soot_jimple_toolkits_callgraph_MethodToContexts$object *, struct _jc_object *) _JC_JCNI_ATTR;

// Virtual methods
extern struct _jc_object *_jc_soot_jimple_toolkits_callgraph_MethodToContexts$method$get$f8a2e6f4762fd0df(_jc_env *, struct _jc_soot_jimple_toolkits_callgraph_MethodToContexts$object *, struct _jc_soot_SootMethod$object *) _JC_JCNI_ATTR;

// Virtual method descriptors
extern _jc_method _jc_soot_jimple_toolkits_callgraph_MethodToContexts$method_info$get$f8a2e6f4762fd0df;

// Virtual methods structure
struct _jc_soot_jimple_toolkits_callgraph_MethodToContexts$vmethods {
	struct _jc_object	*(*get$f8a2e6f4762fd0df)(_jc_env *, struct _jc_soot_jimple_toolkits_callgraph_MethodToContexts$object *, struct _jc_soot_SootMethod$object *) _JC_JCNI_ATTR;
};

// Vtable
struct _jc_soot_jimple_toolkits_callgraph_MethodToContexts$vtable {
	_jc_java_lang_Object$vmethods	java_lang_Object;
	_jc_soot_jimple_toolkits_callgraph_MethodToContexts$vmethods	soot_jimple_toolkits_callgraph_MethodToContexts;
};

// Vtype
struct _jc_soot_jimple_toolkits_callgraph_MethodToContexts$vtype {
	_jc_type			type;
	_jc_soot_jimple_toolkits_callgraph_MethodToContexts$vtable	vtable;
};

// Reference instance fields (subclass)
struct _jc_soot_jimple_toolkits_callgraph_MethodToContexts$sub_refs {
	struct _jc_object	*map;
};

// Reference instance fields (object)
struct _jc_soot_jimple_toolkits_callgraph_MethodToContexts$refs {
    _jc_soot_jimple_toolkits_callgraph_MethodToContexts$sub_refs	soot_jimple_toolkits_callgraph_MethodToContexts;
    _jc_java_lang_Object$sub_refs	java_lang_Object;
};

// Non-reference instance fields (subclass)
struct _jc_soot_jimple_toolkits_callgraph_MethodToContexts$sub_nonrefs {
};

// Non-reference instance fields (object)
struct _jc_soot_jimple_toolkits_callgraph_MethodToContexts$nonrefs {
    _jc_java_lang_Object$sub_nonrefs	java_lang_Object;
    _jc_soot_jimple_toolkits_callgraph_MethodToContexts$sub_nonrefs	soot_jimple_toolkits_callgraph_MethodToContexts;
};

// Object instance structure
struct _jc_soot_jimple_toolkits_callgraph_MethodToContexts$object {
	_jc_soot_jimple_toolkits_callgraph_MethodToContexts$refs	refs[0];
	_jc_word		lockword;
	_jc_soot_jimple_toolkits_callgraph_MethodToContexts$vtype	*vtype;
	_jc_soot_jimple_toolkits_callgraph_MethodToContexts$nonrefs	nonrefs;
};

// Type structure
extern _jc_soot_jimple_toolkits_callgraph_MethodToContexts$vtype _jc_soot_jimple_toolkits_callgraph_MethodToContexts$type;

// Array types class info structures
_JC_DECL_ARRAYS(soot_jimple_toolkits_callgraph_MethodToContexts, type);

// java.lang.Class instance
extern struct _jc_java_lang_Class$object _jc_soot_jimple_toolkits_callgraph_MethodToContexts$class_object;

#endif	/* _JC_soot_jimple_toolkits_callgraph_MethodToContexts_H_ */
